@@ -1,3 +1,53 @@
+# MIT License
+
+# Copyright (c) 2024 Mr-Major-K
+
+# Permission is hereby granted, free of charge, to any person obtaining a copy
+# of this software and associated documentation files (the "Software"), to deal
+# in the Software without restriction, including without limitation the rights
+# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+# copies of the Software, and to permit persons to whom the Software is
+# furnished to do so, subject to the following conditions:
+
+# The above copyright notice and this permission notice shall be included in
+# all copies or substantial portions of the Software.
+
+# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+# SOFTWARE.
+
+"""
+A class for handling log messages in a structured and extensible way.
+
+This class, `Logger`, is designed to provide a simple and customizable
+logging solution for Python applications. It inherits from a base `Handler`
+class and implements specific methods for formatting and outputting log
+messages. The `Logger` class supports various log levels, including DEBUG,
+INFO, WARNING, ERROR, and CRITICAL, allowing for detailed and flexible
+logging.
+
+The `Logger` class is equipped with methods for adding and removing
+handlers, which are responsible for processing and outputting log messages.
+Handlers can be customized to output log messages to various destinations,
+such as the console, files, databases, or external systems. This
+extensibility makes the `Logger` class suitable for a wide range of
+applications, from simple scripts to complex systems.
+
+The `Logger` class also includes methods for logging messages at different
+severity levels, ensuring that developers can easily categorize and
+prioritize log messages based on their importance. Additionally, the class
+provides a mechanism for catching exceptions and logging them,
+facilitating error handling and debugging.
+
+In summary, the `Logger` class offers a straightforward and powerful way
+to integrate logging into Python applications, providing a foundation for
+both basic and advanced logging requirements.
+"""
+
 from datetime import datetime, timezone
 
 from .log_levels import LogLevel
@@ -82,7 +132,7 @@ class Logger:
         """
 
         if loglevel not in self._SUPPORTED_LEVELS:
-            raise InvalidLogLevelError()
+            raise InvalidLogLevelError(loglevel)
 
     def _loglevel_over_min_loglevel(self, loglevel: LogLevel) -> bool:
         """
